/* --------------------------------------------------------------------------
--
-- dsbench/postgres/func_init.sql
--
-- Copyright (C) 2014-2015 Rajko Thon <rajko.thon@leitstern.de>
--                         Mathias Ball <meb@leitstern.de>
--
-- DSBench is free software: you can redistribute it and/or modify it
-- under the terms of the GNU Lesser General Public License as published
-- by the Free Software Foundation, either version 3 of the License, or
-- (at your option) any later version.
--
-- You must obey the GNU Lesser General Public License in all respects for
-- all of the code used.
--
-- DSBench is distributed in the hope that it will be useful, but WITHOUT
-- ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-- FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public
-- License for more details.
--
-------------------------------------------------------------------------- */

create or replace function tpcb_func_p_init (
  i_num_branches          bigint,
  i_num_tellers           bigint,
  i_num_accounts          bigint,
  i_tps                   bigint
)
returns
  void
as $$
  declare v_cnt bigint;
begin
--{
  -- branches
  v_cnt = 0;  

  while (v_cnt < i_num_branches * i_tps)
  loop
  --{
    -- insert
    insert
      into tpcb_branch 
           (
            branch_id,
            branch_balance
           )    
    values (
            v_cnt,
            0
           );
    
    v_cnt = v_cnt + 1;
  --}
  end loop;

  -- tellers
  v_cnt = 0;  

  while (v_cnt < i_num_tellers * i_tps)
  loop
  --{
    -- insert
    insert
      into tpcb_teller 
           (
            teller_id,
            branch_id,
            teller_balance
           )    
    values (
            v_cnt,
            v_cnt / i_num_tellers,
            0
           );

    v_cnt = v_cnt + 1;
  --}
  end loop;

  -- accounts
  v_cnt = 0;  

  while (v_cnt < i_num_accounts * i_tps)
  loop
  --{
    -- insert
    insert
      into tpcb_account 
           (
            account_id,
            branch_id,
            account_balance
           )    
    values (
            v_cnt,
            v_cnt / i_num_accounts,
            0
           );

    v_cnt = v_cnt + 1;
  --}
  end loop;

--}
end;
$$ language plpgsql;
